#!perl
# 
# This file is part of Geo-ICAO
# 
# This software is copyright (c) 2007 by Jerome Quelin.
# 
# This is free software; you can redistribute it and/or modify it under
# the same terms as the Perl 5 programming language system itself.
# 

use Test::More;
eval 'use Test::Kwalitee';
plan skip_all => 'Test::Kwalitee required for testing kwalitee' if $@;
exit;